@@ -4,7 +4,7 @@ use strict;
 use base 'HTML::FormFu::Element::Block';
 use Class::C3;
 
-__PACKAGE__->mk_output_accessors(qw/ legend /);
+__PACKAGE__->mk_output_accessors( qw( legend ) );
 
 sub new {
     my $self = shift->next::method(@_);
@@ -15,11 +15,12 @@ sub new {
 }
 
 sub render_data_non_recursive {
-    my $self = shift;
+    my ( $self, $args ) = @_;
 
     my $render = $self->next::method( {
-            legend => $self->legend,
-            @_ ? %{ $_[0] } : () } );
+        legend => $self->legend,
+        $args ? %$args : (),
+    } );
 
     return $render;
 }
@@ -48,7 +49,7 @@ Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::Block>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
