@@ -4,16 +4,16 @@ use strict;
 use base 'HTML::FormFu::Element::_Field';
 use Class::C3;
 
-use HTML::FormFu::ObjectUtil qw/ _coerce /;
-use HTML::FormFu::Util qw/ append_xml_attribute literal xml_escape /;
-use HTML::FormFu::Attribute qw/ mk_output_accessors /;
+use HTML::FormFu::ObjectUtil qw( _coerce );
+use HTML::FormFu::Util qw( append_xml_attribute literal xml_escape );
+use List::MoreUtils qw( none );
 use Storable qw( dclone );
 use Carp qw( croak );
 
-__PACKAGE__->mk_accessors(qw/ _options empty_first /);
-__PACKAGE__->mk_output_accessors(qw/ empty_first_label/);
+__PACKAGE__->mk_item_accessors( qw( _options empty_first ) );
+__PACKAGE__->mk_output_accessors( qw( empty_first_label ) );
 
-my @ALLOWED_OPTION_KEYS = qw/
+my @ALLOWED_OPTION_KEYS = qw(
     group
     value
     value_xml
@@ -29,12 +29,12 @@ my @ALLOWED_OPTION_KEYS = qw/
     label_attrs
     label_attributes_xml
     label_attrs_xml
-    /;
+);
 
 sub new {
     my $self = shift->next::method(@_);
 
-    $self->_options( [] );
+    $self->_options            ( [] );
     $self->container_attributes( {} );
 
     return $self;
@@ -47,21 +47,22 @@ sub process {
 
     my $args = $self->model_config;
 
-    return unless $args && keys %$args;
+    return if !$args || !keys %$args;
 
     return if @{ $self->options };
 
     # don't run if {options_from_model} is set and is 0
 
     my $option_flag
-        = exists $args->{options_from_model}
-        ? $args->{options_from_model}
-        : 1;
+        = exists $args->{options_from_model} ? $args->{options_from_model}
+        :                                      1
+        ;
 
     return if !$option_flag;
 
     $self->options(
-        [ $self->form->model->options_from_model( $self, $args ) ] );
+        [ $self->form->model->options_from_model( $self, $args ) ]
+    );
 
     return;
 }
@@ -95,11 +96,11 @@ sub options {
 sub _get_empty_first_option {
     my ($self) = @_;
 
-    my $l = $self->empty_first_label || '';
+    my $label = $self->empty_first_label || '';
 
     return {
         value            => '',
-        label            => $l,
+        label            => $label,
         attributes       => {},
         label_attributes => {},
     };
@@ -111,17 +112,13 @@ sub _parse_option {
     eval { my %x = %$item };
 
     if ( !$@ ) {
-
         # was passed a hashref
-
         return $self->_parse_option_hashref($item);
     }
 
     eval { my @x = @$item };
     if ( !$@ ) {
-
         # was passed an arrayref
-
         return {
             value            => $item->[0],
             label            => $item->[1],
@@ -141,13 +138,14 @@ sub _parse_option_hashref {
 
     for my $key (@keys) {
         croak "unknown option argument: '$key'"
-            if !grep { $key eq $_ } @ALLOWED_OPTION_KEYS;
+            if none { $key eq $_ } @ALLOWED_OPTION_KEYS;
 
         my $short = $key;
 
         if ( $short =~ s/attributes/attrs/ ) {
             for my $cmp (@keys) {
                 next if $cmp eq $key;
+                
                 croak "cannot use both '$key' and '$short' arguments"
                     if $cmp eq $short;
             }
@@ -164,10 +162,9 @@ sub _parse_option_hashref {
     }
 
     if ( !exists $item->{attributes} ) {
-        $item->{attributes}
-            = exists $item->{attrs}
-            ? $item->{attrs}
-            : {};
+        $item->{attributes} = exists $item->{attrs} ? $item->{attrs}
+                            :                         {}
+                            ;
     }
 
     if ( exists $item->{attributes_xml} ) {
@@ -184,9 +181,9 @@ sub _parse_option_hashref {
 
     if ( !exists $item->{label_attributes} ) {
         $item->{label_attributes}
-            = exists $item->{label_attrs}
-            ? $item->{label_attrs}
-            : {};
+            = exists $item->{label_attrs} ? $item->{label_attrs}
+            :                               {}
+            ;
     }
 
     if ( exists $item->{label_attributes_xml} ) {
@@ -216,30 +213,32 @@ sub _parse_option_hashref {
         $item->{value} = $self->form->localize( $item->{value_loc} );
     }
 
-    $item->{value} = '' if !defined $item->{value};
+    if ( !defined $item->{value} ) {
+        $item->{value} = '';
+    }
 
     return $item;
 }
 
 sub values {
     my ( $self, $arg ) = @_;
-    my ( @values, @new );
 
     croak "values argument must be a single array-ref of values" if @_ > 2;
 
+    my @values;
+    
     if ( defined $arg ) {
         eval { @values = @$arg };
         croak "values argument must be an array-ref" if $@;
     }
 
-    @new = (
-        map { { value            => $_,
-                label            => ucfirst $_,
-                attributes       => {},
-                label_attributes => {},
-            }
-            } @values
-    );
+    my @new = map { {
+        value            => $_,
+        label            => ucfirst $_,
+        attributes       => {},
+        label_attributes => {},
+        } } @values;
+    
     if ( $self->empty_first ) {
         unshift @new, $self->_get_empty_first_option;
     }
@@ -253,7 +252,8 @@ sub value_range {
     my ( $self, $arg ) = @_;
     my (@values);
 
-    croak "value_range argument must be a single array-ref of values" if @_ > 2;
+    croak "value_range argument must be a single array-ref of values"
+        if @_ > 2;
 
     if ( defined $arg ) {
         eval { @values = @$arg };
@@ -273,6 +273,7 @@ sub prepare_attrs {
 
     my $submitted = $self->form->submitted;
     my $default   = $self->default;
+    
     my $value
         = defined $self->name
         ? $self->get_nested_hash_value( $self->form->input, $self->nested_name )
@@ -295,11 +296,12 @@ sub prepare_attrs {
 }
 
 sub render_data_non_recursive {
-    my $self = shift;
+    my ( $self, $args ) = @_;
 
     my $render = $self->next::method( {
-            options => dclone( $self->_options ),
-            @_ ? %{ $_[0] } : () } );
+        options => dclone( $self->_options ),
+        $args ? %$args : (),
+    } );
 
     $self->_quote_options( $render->{options} );
 
@@ -313,8 +315,9 @@ sub _quote_options {
         $opt->{label} = xml_escape( $opt->{label} );
         $opt->{value} = xml_escape( $opt->{value} );
 
-        $self->_quote_options( $opt->{group} )
-            if exists $opt->{group};
+        if ( exists $opt->{group} ) {
+            $self->_quote_options( $opt->{group} );
+        }
     }
 }
 
@@ -323,10 +326,9 @@ sub string {
 
     $args ||= {};
 
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data;
+    my $render = exists $args->{render_data} ? $args->{render_data}
+               :                               $self->render_data
+               ;
 
     # field wrapper template - start
 
@@ -491,7 +493,7 @@ will be empty.
 Is a sub-class of, and inherits methods from 
 L<HTML::FormFu::Element::_Field>, L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
